@@ -25,7 +25,7 @@ with open('include/setup_module_auto_defines.h', 'w') as f:
     print("\nint setup_module_auto_defines(PyObject * module);\n", file=f)
     print("#endif // __SETUP_MODULE_AUTO_DEFINES_H__", file=f)
 
-ignores = ('(', '#endif', '#define', 'icscm_', 'GCC_MODIFIER', 'VS_MODIFIER', '{', 'ICSNVC40_H', 'ICSNVC40INTERNAL__H_', 'SYellowSettings_SIZE')
+ignores = ('(', '#endif', '#define', 'icscm_', 'GCC_MODIFIER', 'VS_MODIFIER', '{', 'ICSNVC40_H', 'ICSNVC40INTERNAL__H_', 'SYellowSettings_SIZE', 'IS_64BIT_SYSTEM')
 use_enums = True
 with open('src/setup_module_auto_defines.cpp', 'w') as f:
     print(boiler_plate, file=f)
@@ -46,7 +46,9 @@ with open('src/setup_module_auto_defines.cpp', 'w') as f:
                 print("\n#ifdef _USE_INTERNAL_HEADER_ /* ALL THESE DEFINES ARE SPECIFIED IN THE INTERNAL HEADER */\n", file=f)
             inside_enum = False
             inside_comment = False
+            line_number = 0
             for line in fname:
+                line_number += 1
                 if line.lstrip().startswith('//'):
                     continue
                 if inside_enum and '}' in line:
@@ -67,14 +69,16 @@ with open('src/setup_module_auto_defines.cpp', 'w') as f:
                         if ',' in sline[0]:
                             # This removes anything after the comma as we don't need it
                             sline[0] = sline[0].split(',')[0]
+                            # This removes anything after the equal sign as we don't need it
+                            sline[0] = sline[0].split('=')[0]
                         print('\tresult += PyModule_AddIntMacro(module, %s);' % sline[0].replace(',', ''), file=f)
                     continue
                 if '#define' in line:
                     sline = line.split()
-                    #print('\t\t' + str(sline))
+                    # DEBUG: print('\t\t' + str(line_number) + '\t' + str(sline))
                     if any(x in sline[1] for x in ignores):
                         continue
-                    if re.match("^\d+?\.\d+?$", sline[2]) is not None:
+                    if len(sline) >= 3 and re.match("^\d+?\.\d+?$", sline[2]) is not None:
                         # Value is a float
                         print('\tresult += PyModule_AddObject(module, "{0}", PyFloat_FromDouble({0}));'.format(sline[1]), file=f)
                     else:
